@@ -1,5 +1,5 @@
 "check.mc.matrix" <-
-function (mc.matrix){
+function (mc.matrix, tol = .Machine$double.eps){
 erg <- logical(length = length(mc.matrix))
 for(i in 1: length(mc.matrix)){
 if(all(dim(mc.matrix[[i]])==c(2,2))){
@@ -10,9 +10,9 @@ ev <- eigen(mc.matrix[[i]])
 evalue <- ev[["values"]]
 evectors <- ev[["vectors"]]
 d <- diag(log(evalue))
-mc <- evectors%*%d%*%solve(evectors)
+mc <- zapsmall(evectors%*%d%*%solve(evectors))
 diag(mc) <- 1
-erg[i] <- all(mc > 0)
+erg[i] <- all(mc > - tol)
 }
 }
 return(erg)
